<?php

namespace Drupal\trending_topics\Services;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Database\Connection;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * TrendingTopicsService Services for difference Tracker module.
 *
 * @ingroup trending_topics
 */
class TrendingTopicsService {
  use StringTranslationTrait;

  /**
   * A database connection service instance.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * A language manager service instance.
   *
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * TrendingTopicsService constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The Language service.
   */
  public function __construct(Connection $connection,
  LanguageManagerInterface $language_manager) {
    $this->database = $connection;
    $this->languageManager = $language_manager;
  }

  /**
   * Return email addresses for the given email alias.
   */
  public function getTrendingTopics() {
    $current_language = $this->languageManager->getCurrentLanguage()->getId();
    $query = $this->database->select('node_field_data', 'nfd');
    $query->leftJoin('node_counter', 'nc', 'nfd.nid = nc.nid');
    $query->fields('nfd', ['title', 'nid'])
      ->condition('nfd.status', '1')
      ->orderBy('nc.totalcount', 'DESC')
      ->range(0, 5);
    if (!empty($current_language) && strtolower($current_language) != 'und') {
      $query->condition('nfd.langcode', $current_language);
    }
    $results = $query->execute()->fetchAll();
    $trending_topics = '<div id="trending-topics">';
    foreach ($results as $result) {
      $url = Url::fromRoute('entity.node.canonical', array('node' => $result->nid));
      $topic_link = Link::fromTextAndUrl($this->t($result->title), $url);
      $topic_link = $topic_link->toRenderable();
      $trending_topics .= '<div class="trending-topic-list">'.render($topic_link).'</div>';
    }
    $trending_topics .= '</div>';
    return $trending_topics;
  }

}
